@@ -73,13 +73,13 @@ new DynamoDBStreamToLambdaToElasticSearchAndKibana(scope: Construct, id: string,
 
 | **Name**     | **Type**        | **Description** |
 |:-------------|:----------------|-----------------|
-|dynamoTable()|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Retruns an instance of dynamodb.Table created by the construct|
-|lambdaFunction()|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Retruns an instance of lambda.Function created by the construct|
-|userPool()|[`cognito.UserPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPool.html)|Retruns an instance of cognito.UserPool created by the construct|
-|userPoolClient()|[`cognito.UserPoolClient`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolClient.html)|Retruns an instance of cognito.UserPoolClient created by the construct|
-|identityPool()|[`cognito.CfnIdentityPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.CfnIdentityPool.html)|Retruns an instance of cognito.CfnIdentityPool created by the construct|
-|elasticsearchDomain()|[`elasticsearch.CfnDomain`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-elasticsearch.CfnDomain.html)|Retruns an instance of elasticsearch.CfnDomain created by the construct|
-|cloudwatchAlarms()|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Retruns a list of cloudwatch.Alarm created by the construct|
+|dynamoTable()|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-dynamodb.Table.html)|Returns an instance of dynamodb.Table created by the construct|
+|lambdaFunction()|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
+|userPool()|[`cognito.UserPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPool.html)|Returns an instance of cognito.UserPool created by the construct|
+|userPoolClient()|[`cognito.UserPoolClient`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.UserPoolClient.html)|Returns an instance of cognito.UserPoolClient created by the construct|
+|identityPool()|[`cognito.CfnIdentityPool`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cognito.CfnIdentityPool.html)|Returns an instance of cognito.CfnIdentityPool created by the construct|
+|elasticsearchDomain()|[`elasticsearch.CfnDomain`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-elasticsearch.CfnDomain.html)|Returns an instance of elasticsearch.CfnDomain created by the construct|
+|cloudwatchAlarms()|[`cloudwatch.Alarm[]`](https://docs.aws.amazon.com/cdk/api/latest/docs/@aws-cdk_aws-cloudwatch.Alarm.html)|Returns a list of cloudwatch.Alarm created by the construct|
 
 ## Architecture
 
@@ -110,8 +110,9 @@ import aws_cdk.core
 import aws_solutions_konstruk.aws_dynamodb_stream_lambda
 import aws_solutions_konstruk.aws_lambda_elasticsearch_kibana
 import aws_solutions_konstruk.core
+import constructs
 
-__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-konstruk/aws-dynamodb-stream-lambda-elasticsearch-kibana", "0.8.0", __name__, "aws-dynamodb-stream-lambda-elasticsearch-kibana@0.8.0.jsii.tgz")
+from ._jsii import *
 
 
 class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, metaclass=jsii.JSIIMeta, jsii_type="@aws-solutions-konstruk/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibana"):
@@ -149,7 +150,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns a list of cloudwatch.Alarm created by the construct.
+        :summary:: Returns a list of cloudwatch.Alarm created by the construct.
         """
         return jsii.invoke(self, "cloudwatchAlarms", [])
 
@@ -164,7 +165,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of dynamodb.Table created by the construct.
+        :summary:: Returns an instance of dynamodb.Table created by the construct.
         """
         return jsii.invoke(self, "dynamoTable", [])
 
@@ -179,7 +180,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of elasticsearch.CfnDomain created by the construct.
+        :summary:: Returns an instance of elasticsearch.CfnDomain created by the construct.
         """
         return jsii.invoke(self, "elasticsearchDomain", [])
 
@@ -194,7 +195,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of cognito.CfnIdentityPool created by the construct.
+        :summary:: Returns an instance of cognito.CfnIdentityPool created by the construct.
         """
         return jsii.invoke(self, "identityPool", [])
 
@@ -209,7 +210,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of lambda.Function created by the construct.
+        :summary:: Returns an instance of lambda.Function created by the construct.
         """
         return jsii.invoke(self, "lambdaFunction", [])
 
@@ -224,7 +225,7 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of cognito.UserPool created by the construct.
+        :summary:: Returns an instance of cognito.UserPool created by the construct.
         """
         return jsii.invoke(self, "userPool", [])
 
@@ -239,14 +240,14 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibana(aws_cdk.core.Construct, met
         since:
         :since:: 0.8.0
         summary:
-        :summary:: Retruns an instance of cognito.UserPoolClient created by the construct.
+        :summary:: Returns an instance of cognito.UserPoolClient created by the construct.
         """
         return jsii.invoke(self, "userPoolClient", [])
 
 
 @jsii.data_type(jsii_type="@aws-solutions-konstruk/aws-dynamodb-stream-lambda-elasticsearch-kibana.DynamoDBStreamToLambdaToElasticSearchAndKibanaProps", jsii_struct_bases=[], name_mapping={'deploy_lambda': 'deployLambda', 'domain_name': 'domainName', 'dynamo_event_source_props': 'dynamoEventSourceProps', 'dynamo_table_props': 'dynamoTableProps', 'es_domain_props': 'esDomainProps', 'existing_lambda_obj': 'existingLambdaObj', 'lambda_function_props': 'lambdaFunctionProps'})
 class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
-    def __init__(self, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None):
+    def __init__(self, *, deploy_lambda: bool, domain_name: str, dynamo_event_source_props: typing.Optional[aws_cdk.aws_lambda_event_sources.DynamoEventSourceProps]=None, dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps]=None, es_domain_props: typing.Optional[aws_cdk.aws_elasticsearch.CfnDomainProps]=None, existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function]=None, lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps]=None) -> None:
         """
         :param deploy_lambda: Whether to create a new lambda function or use an existing lambda function. If set to false, you must provide a lambda function object as ``existingObj`` Default: - true
         :param domain_name: Cognito & ES Domain Name. Default: - None
@@ -352,6 +353,9 @@ class DynamoDBStreamToLambdaToElasticSearchAndKibanaProps():
         return 'DynamoDBStreamToLambdaToElasticSearchAndKibanaProps(%s)' % ', '.join(k + '=' + repr(v) for k, v in self._values.items())
 
 
-__all__ = ["DynamoDBStreamToLambdaToElasticSearchAndKibana", "DynamoDBStreamToLambdaToElasticSearchAndKibanaProps", "__jsii_assembly__"]
+__all__ = [
+    "DynamoDBStreamToLambdaToElasticSearchAndKibana",
+    "DynamoDBStreamToLambdaToElasticSearchAndKibanaProps",
+]
 
 publication.publish()
