@@ -18,6 +18,12 @@ import aws_cdk.core
 import aws_solutions_konstruk.aws_dynamodb_stream_lambda
 import aws_solutions_konstruk.aws_lambda_elasticsearch_kibana
 import aws_solutions_konstruk.core
-__all__ = []
+import constructs
+
+__jsii_assembly__ = jsii.JSIIAssembly.load("@aws-solutions-konstruk/aws-dynamodb-stream-lambda-elasticsearch-kibana", "0.8.1", __name__[0:-6], "aws-dynamodb-stream-lambda-elasticsearch-kibana@0.8.1.jsii.tgz")
+
+__all__ = [
+    "__jsii_assembly__",
+]
 
 publication.publish()
